@@ -27,14 +27,12 @@ def get_post(
         post_index: int = 0,
         search_type: int = 0,
         search_condition: str = None,
+        search_list: list = None,
         query: bool = False) -> data_type.PostInfo:
-    cmd_list = []
-    cmd_list.append(command.GoMainMenu)
-    cmd_list.append('qs')
-    cmd_list.append(board)
-    cmd_list.append(command.Enter)
-    cmd_list.append(command.Ctrl_C * 2)
-    cmd_list.append(command.Space)
+
+    api._goto_board(board)
+
+    cmd_list = list()
 
     if post_aid is not None:
         cmd_list.append('#' + post_aid)
@@ -55,6 +53,25 @@ def get_post(
             cmd_list.append(search_condition)
             cmd_list.append(command.Enter)
 
+        if search_list is not None:
+            for search_type_, search_condition_ in search_list:
+
+                if search_type_ == data_type.post_search_type.KEYWORD:
+                    cmd_list.append('/')
+                elif search_type_ == data_type.post_search_type.AUTHOR:
+                    cmd_list.append('a')
+                elif search_type_ == data_type.post_search_type.PUSH:
+                    cmd_list.append('Z')
+                elif search_type_ == data_type.post_search_type.MARK:
+                    cmd_list.append('G')
+                elif search_type_ == data_type.post_search_type.MONEY:
+                    cmd_list.append('A')
+
+                cmd_list.append(search_condition_)
+                cmd_list.append(command.Enter)
+
+        cmd_list.append(str(max(1, post_index - 100)))
+        cmd_list.append(command.Enter)
         cmd_list.append(str(post_index))
 
     cmd_list.append(command.Enter)
@@ -248,7 +265,7 @@ def get_post(
 
         push_number = cursor_line
         # print(f'2>{push_number}<')
-        push_number = push_number[7:10]
+        push_number = push_number[7:12]
         # print(push_number)
         push_number = push_number.split(' ')
         # print(PushNumber)
@@ -341,12 +358,12 @@ def get_post(
         return post
 
     # print('=' * 20)
-    # print()
+    # print(origin_post)
     # print('=' * 20)
 
     content_start = '───────────────────────────────────────'
-    content_end = []
-    content_end.append('--\n※ 發信站: 批踢踢實業坊(ptt.cc)')
+    content_end = list()
+    content_end.append('--\n※ 發信站: 批踢踢實業坊')
     content_end.append('--\n※ 發信站: 批踢踢兔(ptt2.cc)')
     content_end.append('--\n※ 發信站: 新批踢踢(ptt2.twbbs.org.tw)')
 
@@ -355,10 +372,10 @@ def get_post(
     board_pattern = re.compile('看板  (.+)')
 
     post_date = None
-    post_content = []
+    post_content = list()
     ip = None
     location = None
-    push_list = []
+    push_list = list()
 
     # 格式確認，亂改的我也沒辦法Q_Q
     origin_post_lines = origin_post.split('\n')
@@ -653,7 +670,7 @@ def get_post(
     push_date_pattern = re.compile('[\d]+/[\d]+ [\d]+:[\d]+')
     push_ip_pattern = re.compile('[\d]+\.[\d]+\.[\d]+\.[\d]+')
 
-    push_list = []
+    push_list = list()
 
     for line in origin_post_lines:
         if line.startswith('推'):
